@@ -23,7 +23,7 @@ from vectorcode.cli_utils import (
 
 @pytest.mark.asyncio
 async def test_config_import_from():
-    with tempfile.TemporaryDirectory(dir="/tmp") as temp_dir:
+    with tempfile.TemporaryDirectory() as temp_dir:
         db_path = os.path.join(temp_dir, "test_db")
         os.makedirs(db_path, exist_ok=True)
         config_dict: Dict[str, Any] = {
@@ -62,7 +62,7 @@ async def test_config_import_from_invalid_path():
 
 @pytest.mark.asyncio
 async def test_config_import_from_db_path_is_file():
-    with tempfile.TemporaryDirectory(dir="/tmp") as temp_dir:
+    with tempfile.TemporaryDirectory() as temp_dir:
         db_path = os.path.join(temp_dir, "test_db_file")
         with open(db_path, "w") as f:
             f.write("test")
@@ -134,7 +134,7 @@ def test_expand_envs_in_dict():
 
 @pytest.mark.asyncio
 async def test_expand_globs():
-    with tempfile.TemporaryDirectory(dir="/tmp") as temp_dir:
+    with tempfile.TemporaryDirectory() as temp_dir:
         file1_path = os.path.join(temp_dir, "file1.txt")
         dir1_path = os.path.join(temp_dir, "dir1")
         file2_path = os.path.join(dir1_path, "file2.txt")
@@ -192,7 +192,7 @@ def test_expand_path():
 
 @pytest.mark.asyncio
 async def test_load_config_file_invalid_json():
-    with tempfile.TemporaryDirectory(dir="/tmp") as temp_dir:
+    with tempfile.TemporaryDirectory() as temp_dir:
         config_path = os.path.join(temp_dir, "config.json")
         with open(config_path, "w") as f:
             f.write("invalid json")
@@ -203,7 +203,7 @@ async def test_load_config_file_invalid_json():
 
 @pytest.mark.asyncio
 async def test_find_project_config_dir_no_anchors():
-    with tempfile.TemporaryDirectory(dir="/tmp") as temp_dir:
+    with tempfile.TemporaryDirectory() as temp_dir:
         project_dir = await find_project_config_dir(temp_dir)
         assert project_dir is None
 
@@ -216,7 +216,7 @@ async def test_expand_globs_nonexistent_path():
 
 @pytest.mark.asyncio
 async def test_load_config_file_empty_file():
-    with tempfile.TemporaryDirectory(dir="/tmp") as temp_dir:
+    with tempfile.TemporaryDirectory() as temp_dir:
         config_path = os.path.join(temp_dir, "config.json")
         with open(config_path, "w") as f:
             f.write("")
@@ -227,7 +227,7 @@ async def test_load_config_file_empty_file():
 
 @pytest.mark.asyncio
 async def test_find_project_config_dir_nested():
-    with tempfile.TemporaryDirectory(dir="/tmp") as temp_dir:
+    with tempfile.TemporaryDirectory() as temp_dir:
         level1_dir = os.path.join(temp_dir, "level1")
         level2_dir = os.path.join(level1_dir, "level2")
         level3_dir = os.path.join(level2_dir, "level3")
@@ -243,20 +243,20 @@ async def test_find_project_config_dir_nested():
 
         # Test finding from level3_dir; should find .vectorcode in level2
         found_dir = await find_project_config_dir(level3_dir)
-        assert found_dir == vectorcode_dir
+        assert found_dir is not None and os.path.samefile(found_dir, vectorcode_dir)
 
         # Test finding from level2_dir; should find .vectorcode in level2
         found_dir = await find_project_config_dir(level2_dir)
-        assert found_dir == vectorcode_dir
+        assert found_dir is not None and os.path.samefile(found_dir, vectorcode_dir)
 
         # Test finding from level1_dir; should find .git in level1
         found_dir = await find_project_config_dir(level1_dir)
-        assert found_dir == git_dir
+        assert found_dir is not None and os.path.samefile(found_dir, git_dir)
 
 
 @pytest.mark.asyncio
 async def test_expand_globs_mixed_paths():
-    with tempfile.TemporaryDirectory(dir="/tmp") as temp_dir:
+    with tempfile.TemporaryDirectory() as temp_dir:
         existing_file = os.path.join(temp_dir, "existing_file.txt")
         with open(existing_file, "w") as f:
             f.write("content")
@@ -291,12 +291,14 @@ def test_find_project_root():
 
         # Test when anchor file exists
         os.makedirs(os.path.join(temp_dir, ".vectorcode"))
-        assert find_project_root(temp_dir) == temp_dir
+        found_dir = find_project_root(temp_dir)
+        assert found_dir is not None and os.path.samefile(found_dir, temp_dir)
 
         # Test when start_from is a file
         test_file = os.path.join(temp_dir, "test_file.txt")
         open(test_file, "a").close()
-        assert find_project_root(test_file) == temp_dir
+        found_dir = find_project_root(test_file)
+        assert found_dir is not None and os.path.samefile(found_dir, temp_dir)
 
 
 @pytest.mark.asyncio
@@ -379,7 +381,7 @@ def test_find_project_root_file_input(tmp_path):
     project_root = find_project_root(temp_file)
 
     # Assert that it returns the parent directory (tmp_path)
-    assert str(project_root) == str(tmp_path)
+    assert os.path.samefile(str(project_root), str(tmp_path))
 
 
 @pytest.mark.asyncio
@@ -398,7 +400,7 @@ async def test_parse_cli_args_clean():
 
 @pytest.mark.asyncio
 async def test_config_import_from_hnsw():
-    with tempfile.TemporaryDirectory(dir="/tmp") as temp_dir:
+    with tempfile.TemporaryDirectory() as temp_dir:
         db_path = os.path.join(temp_dir, "test_db")
         os.makedirs(db_path, exist_ok=True)
         config_dict: Dict[str, Any] = {
